<template>
  <div class="swiper pr">
    <swiper :options="swiperOption" ref="mySwiper">
      <!-- slides -->
      <swiper-slide v-for="(slide, index) in data" :style="slideWidth?`width:${slideWidth};`:''" :key="index">
        <slot :data="slide"></slot>
      </swiper-slide>
      <!-- Optional controls -->
      <div class="swiper-pagination" v-if="isShowPagination" slot="pagination"></div>

      <!-- <div class="swiper-scrollbar"   slot="scrollbar"></div> -->

    </swiper>
    <div class="swiper-button-prev" slot="button-prev" v-if="isShowButton" @click="swiper.slidePrev()">
        <i class="fa fa-chevron-left"></i>
      </div>
      <div class="swiper-button-next" slot="button-next" v-if="isShowButton" @click="swiper.slideNext()">
        <i class="fa fa-chevron-right"></i>
      </div>
    <div class="msg">
      <slot name="msg"/>
    </div>
  </div>
</template>
<script>
import 'swiper/dist/css/swiper.css'
import { swiper, swiperSlide } from 'vue-awesome-swiper'
export default {
  components: {
    swiper,
    swiperSlide
  },
  props: {
    slideWidth: {
      default: '',
      type: String
    },
    isShowPagination: {
      default: false,
      type: Boolean
    },
    isShowButton: {
      default: true,
      type: Boolean
    },
    data: {
      default: () => [],
      type: Array
    }
  },
  data() {
    return {
      swiperOption: {
        pagination: {
          el: '.swiper-pagination',
          clickable: true
        },
        slidesPerView: 'auto',
        spaceBetween: 10
      }
    }
  },
  computed: {
    swiper() {
      return this.$refs.mySwiper.swiper
    }
  },
  mounted() {
    // current swiper instance
    // 然后你就可以使用当前上下文内的swiper对象去做你想做的事了
    console.log('this is current swiper instance object', this.swiper)
    // this.swiper.slideTo(3, 1000, false)
  }
}
</script>
<style lang="scss" scoped>
.swiper {
  .swiper-container {
    padding: 0 20px;
  }
  .swiper-button-prev,
  .swiper-button-next {
    background-image: none;
    display: none;
    i {
      font-size: 45px;
      color: #333;
    }
  }
  .swiper-button-prev {
    left: -10px;
  }
  .swiper-button-next {
    right: -10px;
  }
  &:hover .swiper-button-prev,
  &:hover .swiper-button-next {
    display: block;
  }
  .msg {
    position: absolute;
    left: 0px;
    bottom: 2px;
    width: 100%;
  }
}
</style>
